inputs:
  threads:
    doc: "The number of threads to use. Default: 1. Value must be a positive integer."
    type: long?
    inputBinding:
      prefix: --threads
  kmer:
    doc: "The k-mer size. Default: 20. Value must be in range [1,32]."
    type: long?
    inputBinding:
      prefix: --kmer
  window:
    doc: "The window size. Default: 20. Value must be a positive integer."
    type: long?
    inputBinding:
      prefix: --window
  shape:
    doc: "The shape to use for k-mers. Mutually exclusive with --kmer. Parsed from right to left. Default: . Value must match the pattern '[01]+'."
    type: string?
    inputBinding:
      prefix: --shape
  fpr:
    doc: "The false positive rate. Default: 0.05. Value must be in range [0.000000,1.000000]."
    type: double?
    inputBinding:
      prefix: --fpr
  hash:
    doc: "The number of hash functions to use. Default: 2. Value must be in range [1,5]."
    type: long?
    inputBinding:
      prefix: --hash
  parts:
    doc: "Splits the index in this many parts. Not available for the HIBF. Default: 1. Value must be a power of two."
    type: long?
    inputBinding:
      prefix: --parts
  output_name:
    doc: " A valid path for the output file. Write permissions must be granted."
    type: string
    inputBinding:
      prefix: --output
  sequences:
    type:
      type: array
      items:
        type: array
        items: File
outputs:
  index:
    type: File
    outputBinding:
      glob: $(inputs.output_name)
label: Raptor-build
doc: "Constructs a Raptor index.\nThe input may be a layout file from \\fBraptor layout\\fP, a list of minimiser files produced from \\fBraptor prepare\\fP, or a file with a list of files to process.\n"
cwlVersion: v1.2
class: CommandLineTool
baseCommand:
  - raptor
  - build
requirements:
  InlineJavascriptRequirement: {}
  InitialWorkDirRequirement:
    listing:
      - $(inputs.sequences.flat())
      - entryname: input_bins_filepaths.txt
        entry: "${\n   var bins = \"\";\n   for (var i = 0; i < inputs.sequences.length; i++) {\n      var currentBin = inputs.sequences[i];\n      for (var j = 0; j < currentBin.length; j++) {\n        bins += currentBin[j].basename + \" \";\n      }\n      bins += \"\\n\";\n   }\n   return bins;\n}\n"
arguments:
  - --input
  - input_bins_filepaths.txt
