inputs:
  input-file:
    doc: "The input must be a file containing paths to sequence data you wish to estimate; one filepath per line. If your file contains auxiliary information (e.g. species IDs), your file must be tab-separated. "
    type: string
    inputBinding:
      prefix: --input-file
  kmer-size:
    doc: "The k-mer size influences the size estimates of the input. Choosing a k-mer size that is too small for your data will result in files appearing more similar than they really are. Likewise, a large k-mer size might miss out on certain similarities. For DNA sequences, a k-mer size between [16,32] has proven to work well. Default: 19. "
    type: long?
    inputBinding:
      prefix: --kmer-size
  tmax:
    doc: "Limits the number of technical bins on each level of the HIBF. Choosing a good tmax is not trivial. The smaller tmax, the more levels the layout needs to represent the data. This results in a higher space consumption of the index. While querying each individual level is cheap, querying many levels might also lead to an increased runtime. A good tmax is usually the square root of the number of user bins/samples rounded to the next multiple of 64. Note that your tmax will always be rounded to the next multiple of 64. At the expense of a longer runtime, you can enable the statistic mode that determines the best tmax for your data set. See the advanced option --determine-best-tmax Default: 0. "
    type: long?
    inputBinding:
      prefix: --tmax
  num-hash-functions:
    doc: "The number of hash functions to use when building the HIBF from the resulting layout. This parameter is needed to correctly estimate the index size when computing the layout. Default: 2. "
    type: long?
    inputBinding:
      prefix: --num-hash-functions
  false-positive-rate:
    doc: "The false positive rate you aim for when building the HIBF from the resulting layout. This parameter is needed to correctly estimate the index size when computing the layout. Default: 0.05. "
    type: double?
    inputBinding:
      prefix: --false-positive-rate
  output-filename:
    doc: "A file name for the resulting layout. Default: \"binning.out\". "
    type: string?
    inputBinding:
      prefix: --output-filename
  threads:
    doc: "The number of threads to use. Currently, only merging of sketches is parallelized, so if the flag --disable-rearrangement is set, --threads will have no effect. Default: 1. Value must be in range [1,18446744073709551615]."
    type: long?
    inputBinding:
      prefix: --threads
  alpha:
    doc: "The layout algorithm optimizes the space consumption of the resulting HIBF but currently has no means of optimizing the runtime for querying such an HIBF. In general, the ratio of merged bins and split bins influences the query time because a merged bin always triggers another search on a lower level. To influence this ratio, alpha can be used. The higher alpha, the less merged bins are chosen in the layout. This improves query times but leads to a bigger index. Default: 1.2. "
    type: double?
    inputBinding:
      prefix: --alpha
  max-rearrangement-ratio:
    doc: "When the flag --disable-rearrangement is \\fBnot\\fP set, this option can influence the rearrangement algorithm. The algorithm only rearranges the order of user bins in fixed intervals. The higher --max-rearrangement-ratio, the larger the intervals. This potentially improves the layout, but increases the runtime of the layout algorithm. Default: 0.5. Value must be in range [0.000000,1.000000]."
    type: double?
    inputBinding:
      prefix: --max-rearrangement-ratio
  sketch-bits:
    doc: "The number of bits the HyperLogLog sketch should use to distribute the values into bins. Default: 12. Value must be in range [5,32]."
    type: long?
    inputBinding:
      prefix: --sketch-bits
  output-sketches-to:
    doc: "If you supply a directory path with this option, the hyperloglog sketches of your input will be stored in the respective path; one .hll file per input file. Default: \"\". "
    type: string?
    inputBinding:
      prefix: --output-sketches-to
outputs:
  {}
label: Raptor-layout
doc: "Computes an HIBF layout that tries to minimize the disk space consumption of the resulting index. The space is estimated using a k-mer count per user bin which represents the potential denisity in a technical bin in an interleaved Bloom filter.  You can pass the resulting layout to raptor (https://github.com/seqan/raptor) to build the index and conduct queries.\n"
cwlVersion: v1.2
class: CommandLineTool
baseCommand:
  - raptor
  - layout
